/****************************************************************************
**
** Reference :
**
** http://developer.qt.nokia.com/quarterly/view/location_and_mapping_services
** http://www.developer.nokia.com/Resources/Library/Porting_to_Qt/porting-from-windows-phone-to-qt/technology-comparison/maps-and-location.html
**
****************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.location 1.2

Page {
    id: mainPage
    orientationLock: PageOrientation.LockPortrait

    // For MapCircle
    property int mapCircle_radius: (map.maximumZoomLevel * 10) * ((map.maximumZoomLevel - zoomSlider.value) / (map.maximumZoomLevel - map.minimumZoomLevel));
    property int mapCircle_z_value: 5;

    Column {
        id: columnContainer_MainPage

        Rectangle {
            id: rectMap

            width: mapWidth
            height: mapHeight

            Map {
                id: map
                anchors.fill: parent
                zoomLevel: zoomSlider.value
                center: Coordinate {
                    latitude: myLatitude
                    longitude: myLongitude
                }
                plugin: Plugin {
                    name: "nokia"
                }

                MapCircle {
                    id: myOrigin_MapCircle
                    color: colour_Origin_MapCircle
                    radius: mapCircle_radius
                    z: mapCircle_z_value
                    center: Coordinate {latitude: origin_Latitude; longitude: origin_Longitude}
                }

                MapCircle {
                    id: myPosition
                    color: colour_CurrentLocation_MapCircle
                    radius: mapCircle_radius
                    z: mapCircle_z_value
                    center: myPositionSource.position.coordinate
                }
            }

            MouseArea {
                id: area
                anchors.fill: parent
                property real startX: 0
                property real startY: 0

                onPressed: {
                    startX = mouse.x
                    startY = mouse.y
                }

                onPositionChanged: {
                    var dx = mouse.x - startX
                    var dy = mouse.y - startY
                    var pos = map.toScreenPosition(map.center)
                    pos.x -= dx
                    pos.y -= dy
                    map.center = map.toCoordinate(pos)
                    startX = mouse.x
                    startY = mouse.y
                }
            }

            Item {

                id: rectSlider

                width: zoomSlider.width
                height: heightCell
                anchors.bottom: parent.bottom

                Slider {
                    id: zoomSlider

                    width: mapWidth

                    anchors.horizontalCenter: parent.horizontalCenter

                    minimumValue: map.minimumZoomLevel
                    maximumValue: map.maximumZoomLevel
                    value: 10
                }
            }
        }

        Rectangle {

            id: rectMapButtons

            width: rowMapButtons.width
            height: heightCell

            signal clicked(variant mapType)

            Row {
                id: rowMapButtons

                spacing: 2

                Item {
                    width: streetButton.width
                    height: streetButton.height

                    MapButton {
                        id: streetButton

                        width: mapWidth / numberOfButtons
                        height: heightCell

                        text: "Street"
                        mapType: Map.StreetMap
                        onClicked: map.mapType = mapType
                    }
                }

                Item {
                    width: terrainButton.width
                    height: terrainButton.height

                    MapButton {
                        id: terrainButton

                        width: mapWidth / numberOfButtons
                        height: heightCell

                        text: "Terrain"
                        mapType: Map.TerrainMap
                        onClicked: map.mapType = mapType
                    }
                }

                Item {
                    width: satelliteButton.width
                    height: satelliteButton.height

                    MapButton {
                        id: satelliteButton

                        width: mapWidth / numberOfButtons
                        height: heightCell

                        text: "Satellite"
                        mapType: Map.SatelliteMapDay
                        onClicked: map.mapType = mapType
                    }
                }
            }
        }

        Item {

            width: flickableInfo.width
            height: flickableInfo.height

            Flickable {
                id: flickableInfo
                width: mapWidth
                height: mainPage.height - (rectMap.height + rectMapButtons.height)
                contentWidth: columnFlickable.width
                contentHeight: columnFlickable.height
                clip: true

                Column {
                    id: columnFlickable

                    //Current Location
                    Text {
                        width: columnContainer_MainPage.width;
                        height: heightCell

                        text: "My Location :";
                        color: colour_CurrentLocation_MapCircle

                        style: Text.Raised;
                        styleColor: "black"

                        font {
                            bold: true
                            pointSize: fontSize_Header
                        }
                    }

                    Row {

                        Text {
                            width: widthColumn1;
                            height: heightCell

                            text: "Longitude : " + myLongitude;

                            elide: Text.ElideRight
                            style: Text.Raised;
                            styleColor: "black"

                            font {
                                pointSize: fontSize_Info
                            }
                        }

                        Text {
                            width: widthColumn2;
                            height: heightCell

                            text: "X : " + myX + " m";

                            elide: Text.ElideRight
                            style: Text.Raised;
                            styleColor: "black"

                            font {
                                pointSize: fontSize_Info
                            }
                        }
                    }

                    Row {
                        Text {
                            width: widthColumn1;
                            height: heightCell

                            text: "Latitude : " + myLatitude;

                            elide: Text.ElideRight
                            style: Text.Raised;
                            styleColor: "black"

                            font {
                                pointSize: fontSize_Info
                            }
                        }

                        Text {
                            width: widthColumn2;
                            height: heightCell

                            text: "Y : " + myY + " m";

                            elide: Text.ElideRight
                            style: Text.Raised;
                            styleColor: "black"

                            font {
                                pointSize: fontSize_Info
                            }
                        }
                    }

                    //Origin
                    Text {
                        width: columnContainer_MainPage.width;
                        height: heightCell

                        text: "Origin :";
                        color: colour_Origin_MapCircle

                        style: Text.Raised;
                        styleColor: "black"

                        font {
                            bold: true
                            pointSize: fontSize_Header
                        }
                    }

                    Text {
                        width: columnContainer_MainPage.width;
                        height: heightCell

                        text: "Longitude : " + origin_Longitude;

                        elide: Text.ElideRight
                        style: Text.Raised;
                        styleColor: "black"

                        font {
                            pointSize: fontSize_Info
                        }
                    }

                    Text {
                        width: columnContainer_MainPage.width;
                        height: heightCell

                        text: "Latitude : " + origin_Latitude;

                        elide: Text.ElideRight
                        style: Text.Raised;
                        styleColor: "black"

                        font {
                            pointSize: fontSize_Info
                        }
                    }
                }
            }

            ScrollDecorator {
                flickableItem: flickableInfo
            }
        }
    }
}
