import QtQuick 1.1
import com.nokia.meego 1.0

import "GPS_Functions.js" as GPS_Functions

Page {
    id: originPage
    orientationLock: PageOrientation.LockPortrait

    property int rectWidth: originPage.width
    property double temp_Origin_Latitude_DD
    property double temp_Origin_Longitude_DD

    Rectangle {

        width: rectWidth
        height: originPage.height

        Column {
            id: columnContainer_OriginPage

            spacing: columnSpacing

            // Title - Origin
            Rectangle {

                width: rectWidth
                height: heightCell

                Text {

                    text: "Origin"
                    color: colorHeader

                    anchors.centerIn: parent

                    style: Text.Raised;
                    styleColor: "black"

                    font {
                        bold: true
                        pointSize: fontSize_Header
                    }
                }
            }

            // Label - Decimal Degree
            Rectangle {

                width: rectWidth
                height: heightCell

                Text {

                    text: "Decimal Degree"
                    color: colorSecondaryHeader
                    anchors.centerIn: parent

                    font {
                        pointSize: fontSize_Info
                    }
                }
            }

            // Latitude
            Rectangle {

            width: widthRectDisplay
            height: heightRectDisplay

                Row {
                    width: parent.width
                    height: parent.height

                    spacing: rowSpacing

                    Text {
                        text: "Latitude :"
                        focus: true
                        width: widthEntryTextInput
                        height: heightEntryTextInput
                        anchors.verticalCenter: parent.verticalCenter

                        font {
                            pointSize: fontSize_Info
                        }
                    }

                    FocusScope {

                        width: widthEntryTextRect
                        height: heightEntryTextRect

                        Rectangle {
                            width: widthEntryTextRect
                            height: heightEntryTextRect
                            anchors.verticalCenter: parent.verticalCenter
                            border.color: "blue"
                            border.width: borderWidthEntryTextRect
                            radius: radiusEntryTextRect

                            TextInput {
                                id: txtOrigin_Latitude_DD
                                focus: true
                                anchors.centerIn: parent
                                width: widthEntryTextInput
                                height: heightEntryTextInput
                                text: temp_Origin_Latitude_DD
                                //inputMask: inputMask_Latitude_DD

                                validator: DoubleValidator{
                                    bottom: lowerbound_Latitude_DD;
                                    top: upperbound_Latitude_DD;
                                }

                                onAccepted: {
                                    temp_Origin_Latitude_DD = parseFloat(txtOrigin_Latitude_DD.text);
                                    console.debug("OnAccepted Event for Latitude : " + temp_Origin_Latitude_DD);
                                    closeSoftwareInputPanel();
                                }

                                maximumLength: maxLength_Latitude_DD

                                font {
                                    pointSize: fontSize_Info
                                }
                            }
                        }
                    }
                }
            }

            // Longitude
            Rectangle {

                width: widthRectDisplay
                height: heightRectDisplay

                Row {
                    width: parent.width
                    height: parent.height

                    spacing: rowSpacing

                    Text {
                        text: "Longitude :"
                        width: widthEntryTextInput
                        height: heightEntryTextInput
                        anchors.verticalCenter: parent.verticalCenter

                        font {
                            pointSize: fontSize_Info
                        }
                    }

                    FocusScope {

                        width: widthEntryTextRect
                        height: heightEntryTextRect

                        Rectangle {
                            width: widthEntryTextRect
                            height: heightEntryTextRect
                            anchors.verticalCenter: parent.verticalCenter
                            border.color: "blue"
                            border.width: borderWidthEntryTextRect
                            radius: radiusEntryTextRect

                            TextInput {
                                id: txtOrigin_Longitude_DD
                                focus: true
                                anchors.centerIn: parent
                                width: widthEntryTextInput
                                height: heightEntryTextInput
                                text: temp_Origin_Longitude_DD
                                //inputMask: inputMask_Longitude_DD

                                validator: DoubleValidator{
                                    bottom: lowerbound_Longitude_DD;
                                    top: upperbound_Longitude_DD;
                                }

                                onAccepted: {
                                    temp_Origin_Longitude_DD = parseFloat(txtOrigin_Longitude_DD.text);
                                    console.debug("OnAccepted Event for Longitude : " + temp_Origin_Longitude_DD);
                                    closeSoftwareInputPanel();
                                }

                                maximumLength: maxLength_Longitude_DD

                                font {
                                    pointSize: fontSize_Info
                                }
                            }
                        }
                    }
                }
            }

            // Accept button
            Rectangle {
                width: rectWidth
                height: heightRectDisplay

                Button {
                    id: acceptButton

                    text: "Accept"
                    anchors.centerIn: parent

                    onClicked: {
                        console.debug("Updating origin's coordinates");
                        origin_Latitude = temp_Origin_Latitude_DD.toFixed(6);
                        origin_Longitude = temp_Origin_Longitude_DD.toFixed(6);
                        console.debug("Updated Latitude : " + origin_Latitude);
                        console.debug("Updated Longitude : " + origin_Longitude);
                    }
                }
            }
        }
    }
}
