//Latitude North is from 0 to 90, South is from 0 to -90
//Longitude East is from 0 to 180, West is from 0 to -180

import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.location 1.2

import "GPS_Functions.js" as GPS_Functions

PageStackWindow {
    id: appWindow

    initialPage: Tab_Page {}

    // For Map display
    property int mapWidth: initialPage.width
    property int mapHeight: 400

    //Number of MapTypeButtons
    property int numberOfButtons: 3

    // For text display
    property int widthColumn1: mapWidth - 150
    property int widthColumn2: widthColumn1
    property int heightCell: 50
    property int columnSpacing: 10
    property int rowSpacing: 10

    property int fontSize_Header: 20
    property int fontSize_Info: 15
    property variant colorHeader: "blue"
    property variant colorSecondaryHeader: "steelblue"

    // For Entry - Rectangle
    property int heightRectDisplay: 60
    property int widthRectDisplay: 200

    // For Entry - TextInput's Outer Rect
    property int heightEntryTextRect: heightRectDisplay - 10
    property int widthEntryTextRect: 200
    property int borderWidthEntryTextRect: 5
    property int radiusEntryTextRect: 5

    // For Entry - TextInput
    property int heightEntryTextInput: heightEntryTextRect - 20
    property int widthEntryTextInput: widthEntryTextRect - 50

    // For current location's coordinate
    property double myLatitude: myPositionSource.position.coordinate.latitude.toFixed(precisionDD)
    property double myLongitude:  myPositionSource.position.coordinate.longitude.toFixed(precisionDD)
    property double myX: GPS_Functions.long2x(origin_Latitude, origin_Longitude, myLongitude)
    property double myY: GPS_Functions.lat2y(origin_Latitude, myLatitude)

    // For origin's coordinate
    property double origin_Latitude
    property double origin_Longitude

    // For Decimal Degree's input entry
    property int precisionDD: 6
    property string inputMask_Latitude_DD: "#00.000000"
    property int maxLength_Latitude_DD: 10
    property double lowerbound_Latitude_DD: -90.000000
    property double upperbound_Latitude_DD: 90.000000
    property string inputMask_Longitude_DD: "#000.000000"
    property int maxLength_Longitude_DD: 11
    property double lowerbound_Longitude_DD: -180.000000
    property double upperbound_Longitude_DD: 180.000000

    property variant colour_Origin_MapCircle: "yellow"
    property variant colour_CurrentLocation_MapCircle: "green"

    PositionSource {
        id: myPositionSource
        active: true
        updateInterval: 10000
        onPositionChanged: {
            console.log("Position changed in current location's PositionSource : ")
            console.log("Latitude : " + myLatitude)
            console.log("Longitude : " + myLongitude)
            console.log("x : " + myX)
            console.log("y : " + myY)

        }
    }

    PositionSource {
        id: myOriginPositionSource
        active: true
        updateInterval: 1000
        onPositionChanged: {
            myOriginPositionSource.active = false;
            origin_Latitude = myOriginPositionSource.position.coordinate.latitude.toFixed(precisionDD);
            origin_Longitude = myOriginPositionSource.position.coordinate.longitude.toFixed(precisionDD);
            console.log("Position changed in Origin's PositionSource : ")
            console.log("Origin's Latitude : " + origin_Latitude)
            console.log("Origin's Longitude : " + origin_Longitude)
        }
    }
}
